@@ -213,6 +213,8 @@ $apt_allow_unauthenticated = {apt_allow_unauthenticated};
 
         if "Arch-All" in self._breq:
             sbuild_cmd += ["--arch-all"]
+        else:
+            sbuild_cmd += ["--no-arch-all"]  # Be sure to set explicitly: sbuild >= 0.77 does not seem to use this as default any more?
 
         if "Run-Lintian" in self._breq:
             sbuild_cmd += ["--run-lintian"]
@@ -220,6 +222,8 @@ $apt_allow_unauthenticated = {apt_allow_unauthenticated};
             if mini_buildd.misc.Distribution(self.distribution).has_lintian_suppress():
                 sbuild_cmd += ["--lintian-opts", "--suppress-tags=bad-distribution-in-changes-file"]
             sbuild_cmd += ["--lintian-opts", self._breq["Run-Lintian"]]
+        else:
+            sbuild_cmd += ["--no-run-lintian"]
 
         if "sbuild" in mini_buildd.setup.DEBUG:
             sbuild_cmd += ["--debug"]
@@ -241,7 +245,7 @@ $apt_allow_unauthenticated = {apt_allow_unauthenticated};
                                                 cwd=self._build_dir,
                                                 env=mini_buildd.call.taint_env({"HOME": self._build_dir,
                                                                                 "GNUPGHOME": os.path.join(mini_buildd.setup.HOME_DIR, ".gnupg"),
-                                                                                "DEB_BUILD_OPTIONS": "parallel={j}".format(j=self._sbuild_jobs)}),
+                                                                                "DEB_BUILD_OPTIONS": "{d} parallel={j}".format(d=self._breq.get("Deb-Build-Options", ""), j=self._sbuild_jobs)}),
                                                 stdout=l, stderr=subprocess.STDOUT)
             retval = sbuild_call.retval
 
