@@ -156,12 +156,21 @@ def call_sequence(calls, run_as_root=False, rollback_only=False, **kwargs):
 
 
 def call_with_retry(call, retry_max_tries=5, retry_sleep=1, retry_failed_cleanup=None, **kwargs):
+    """Run call repeatedly until it succeeds (retval 0). In case
+    retry_max_tries is reached, the error from the last try is raised.
+
+    >>> call_with_retry(["/bin/true"])
+    >>> call_with_retry(["/bin/false"])
+    Traceback (most recent call last):
+      ...
+    Exception: Call failed with retval 1: '/bin/false '
+    """
     for t in range(retry_max_tries):
         try:
             Call(call, **kwargs).log().check()
-            break
-        except Exception as e:
-            if t > retry_max_tries:
+            return
+        except BaseException as e:
+            if t >= retry_max_tries - 1:
                 raise
             LOG.error("Retrying call in {s} seconds [retry #{t}]: {e}".format(s=retry_sleep, t=t, e=e))
             if retry_failed_cleanup:
@@ -180,6 +189,6 @@ def sbuild_keys_workaround():
         else:
             t = tempfile.mkdtemp()
             LOG.warn("One-time generation of sbuild keys (may take some time)...")
-            Call(["sbuild-update", "--keygen"], env=taint_env({"HOME": t})).log().check()
+            Call(["sbuild-update", "--keygen"], env=taint_env({"HOME": t})).log()
             shutil.rmtree(t)
             LOG.info("One-time generation of sbuild keys done")
