@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 from __future__ import absolute_import
+from __future__ import print_function
 
 import os
 import platform
+import sys
+import argparse
 import copy
 import datetime
 import shutil
@@ -36,6 +39,15 @@ LOG = logging.getLogger(__name__)
 PY2_HAS_URLLIB2_CAFILE = LooseVersion(platform.python_version()) >= LooseVersion("2.7.9")
 
 
+class ArgparseVersion2StdoutAction(argparse.Action):
+    """
+    python 2 compat: workaround for https://bugs.python.org/issue18920 (version goes to stderr).
+    """
+    def __call__(self, parser, namespace, values, option_string=None):
+        print(mini_buildd.__version__)
+        sys.exit(0)
+
+
 def open_utf8(path, mode="r", **kwargs):
     return codecs.open(path, mode, encoding=mini_buildd.setup.CHAR_ENCODING, **kwargs)
 
@@ -240,6 +252,14 @@ def codename_has_lintian_suppress(codename):
     return codename not in ["buzz", "rex", "bo", "hamm", "slink", "potato", "woody", "sarge", "etch", "lenny"]
 
 
+def codename_produces_ddeb_appendix(codename):
+    """
+    Some Ubuntu codenames produce 'ddeb' file appendix for automated debug packages.
+    reprepro can't handle these yet -- so this is needed for a workaround for the wizard setup.
+    """
+    return codename in ["bionic", "cosmic"]
+
+
 class Distribution(object):
     """
     A mini-buildd distribution string.
