@@ -86,7 +86,7 @@ automatically added.""")
 
     sbuild_jobs = django.db.models.IntegerField(
         default=1,
-        help_text="Degree of parallelism per build (via sbuild's '--jobs' option).")
+        help_text="Degree of parallelism per build (via DEB_BUILD_OPTIONS).")
 
     # EMail options
     # DEPRECTATED/UNUSED: With the switch to django mail framework, this is now configured via the --smtp command line argument.
